==> protozero-docs-1.8.0-1-any.pkg.tar.zst: usr/share/doc/protozero/search/all_c.js <==
var searchData=
[
  ['field_0',['field',['../md_doc_2advanced.html#autotoc_md32',1,'How many items are there in a repeated packed field?'],['../md_doc_2tutorial.html#autotoc_md44',1,'If you only need a single field']]],
  ['fields_1',['fields',['../md_doc_2tutorial.html#autotoc_md46',1,'Handling repeated packed fields'],['../md_doc_2tutorial.html#autotoc_md61',1,'Handling repeated packed fields'],['../md_doc_2tutorial.html#autotoc_md45',1,'Handling scalar fields'],['../md_doc_2tutorial.html#autotoc_md60',1,'Handling scalar fields'],['../md_doc_2cheatsheet.html#autotoc_md37',1,'Packed repeated fields'],['../md_doc_2advanced.html#autotoc_md30',1,'Vectored input for length-delimited fields']]],
  ['fields_20in_20messages_2',['Repeated fields in messages',['../md_doc_2advanced.html#autotoc_md24',1,'']]],
  ['fixed_5fsize_5fbuffer_5fadaptor_3',['fixed_size_buffer_adaptor',['../classprotozero_1_1fixed__size__buffer__adaptor.html',1,'protozero::fixed_size_buffer_adaptor'],['../classprotozero_1_1fixed__size__buffer__adaptor.html#a6dd1c97e4ae69e444b8e5ed398d379bc',1,'protozero::fixed_size_buffer_adaptor::fixed_size_buffer_adaptor(char *data, std::size_t capacity) noexcept'],['../classprotozero_1_1fixed__size__buffer__adaptor.html#a2a1b492a65805ff3518898d66c76b1de',1,'protozero::fixed_size_buffer_adaptor::fixed_size_buffer_adaptor(T &amp;container)']]],
  ['for_20length_20delimited_20fields_4',['Vectored input for length-delimited fields',['../md_doc_2advanced.html#autotoc_md30',1,'']]],
  ['from_20em_20v1_203_200_20em_20to_20em_20v1_204_200_20em_5',['Upgrading from &lt;em&gt;v1.3.0&lt;/em&gt; to &lt;em&gt;v1.4.0&lt;/em&gt;',['../md_UPGRADING.html#autotoc_md17',1,'']]],
  ['from_20em_20v1_204_200_20em_20to_20em_20v1_204_201_20em_6',['Upgrading from &lt;em&gt;v1.4.0&lt;/em&gt; to &lt;em&gt;v1.4.1&lt;/em&gt;',['../md_UPGRADING.html#autotoc_md16',1,'']]],
  ['from_20em_20v1_204_204_20em_20to_20em_20v1_204_205_20em_7',['Upgrading from &lt;em&gt;v1.4.4&lt;/em&gt; to &lt;em&gt;v1.4.5&lt;/em&gt;',['../md_UPGRADING.html#autotoc_md15',1,'']]],
  ['from_20em_20v1_204_205_20em_20to_20em_20v1_205_200_20em_8',['Upgrading from &lt;em&gt;v1.4.5&lt;/em&gt; to &lt;em&gt;v1.5.0&lt;/em&gt;',['../md_UPGRADING.html#autotoc_md14',1,'']]],
  ['from_20em_20v1_205_20em_20to_20em_20v1_206_200_20em_9',['Upgrading from &lt;em&gt;v1.5&lt;/em&gt; to &lt;em&gt;v1.6.0&lt;/em&gt;',['../md_UPGRADING.html#autotoc_md13',1,'']]],
  ['from_20em_20v1_206_20em_20to_20em_20v1_207_20em_10',['Upgrading from &lt;em&gt;v1.6&lt;/em&gt; to &lt;em&gt;v1.7&lt;/em&gt;',['../md_UPGRADING.html#autotoc_md12',1,'']]],
  ['front_11',['front',['../classprotozero_1_1iterator__range.html#a514e051415f0f47ce68d04ab32eb4ff1',1,'protozero::iterator_range']]],
  ['functions_12',['Functions',['../md_doc_2advanced.html#autotoc_md29',1,'']]],
  ['functions_13',['functions',['../md_doc_2advanced.html#autotoc_md28',1,'Using low-level functions'],['../md_doc_2advanced.html#autotoc_md27',1,'Using the low-level varint and zigzag encoding and decoding functions']]]
];

==> protozero-docs-1.8.1-1-any.pkg.tar.zst: usr/share/doc/protozero/search/all_c.js <==
var searchData=
[
  ['field_0',['field',['../md_doc_2advanced.html#autotoc_md32',1,'How many items are there in a repeated packed field?'],['../md_doc_2tutorial.html#autotoc_md44',1,'If you only need a single field']]],
  ['fields_1',['fields',['../md_doc_2tutorial.html#autotoc_md46',1,'Handling repeated packed fields'],['../md_doc_2tutorial.html#autotoc_md61',1,'Handling repeated packed fields'],['../md_doc_2tutorial.html#autotoc_md45',1,'Handling scalar fields'],['../md_doc_2tutorial.html#autotoc_md60',1,'Handling scalar fields'],['../md_doc_2cheatsheet.html#autotoc_md37',1,'Packed repeated fields'],['../md_doc_2advanced.html#autotoc_md30',1,'Vectored input for length-delimited fields']]],
  ['fields_20in_20messages_2',['Repeated fields in messages',['../md_doc_2advanced.html#autotoc_md24',1,'']]],
  ['fixed_5fsize_5fbuffer_5fadaptor_3',['fixed_size_buffer_adaptor',['../classprotozero_1_1fixed__size__buffer__adaptor.html',1,'protozero::fixed_size_buffer_adaptor'],['../classprotozero_1_1fixed__size__buffer__adaptor.html#a6dd1c97e4ae69e444b8e5ed398d379bc',1,'protozero::fixed_size_buffer_adaptor::fixed_size_buffer_adaptor(char *data, std::size_t capacity) noexcept'],['../classprotozero_1_1fixed__size__buffer__adaptor.html#a2a1b492a65805ff3518898d66c76b1de',1,'protozero::fixed_size_buffer_adaptor::fixed_size_buffer_adaptor(T &amp;container)']]],
  ['for_20length_20delimited_20fields_4',['Vectored input for length-delimited fields',['../md_doc_2advanced.html#autotoc_md30',1,'']]],
  ['from_20v1_203_200_20to_20v1_204_200_5',['Upgrading from &lt;em&gt;v1.3.0&lt;/em&gt; to &lt;em&gt;v1.4.0&lt;/em&gt;',['../md_UPGRADING.html#autotoc_md17',1,'']]],
  ['from_20v1_204_200_20to_20v1_204_201_6',['Upgrading from &lt;em&gt;v1.4.0&lt;/em&gt; to &lt;em&gt;v1.4.1&lt;/em&gt;',['../md_UPGRADING.html#autotoc_md16',1,'']]],
  ['from_20v1_204_204_20to_20v1_204_205_7',['Upgrading from &lt;em&gt;v1.4.4&lt;/em&gt; to &lt;em&gt;v1.4.5&lt;/em&gt;',['../md_UPGRADING.html#autotoc_md15',1,'']]],
  ['from_20v1_204_205_20to_20v1_205_200_8',['Upgrading from &lt;em&gt;v1.4.5&lt;/em&gt; to &lt;em&gt;v1.5.0&lt;/em&gt;',['../md_UPGRADING.html#autotoc_md14',1,'']]],
  ['from_20v1_205_20to_20v1_206_200_9',['Upgrading from &lt;em&gt;v1.5&lt;/em&gt; to &lt;em&gt;v1.6.0&lt;/em&gt;',['../md_UPGRADING.html#autotoc_md13',1,'']]],
  ['from_20v1_206_20to_20v1_207_10',['Upgrading from &lt;em&gt;v1.6&lt;/em&gt; to &lt;em&gt;v1.7&lt;/em&gt;',['../md_UPGRADING.html#autotoc_md12',1,'']]],
  ['front_11',['front',['../classprotozero_1_1iterator__range.html#a514e051415f0f47ce68d04ab32eb4ff1',1,'protozero::iterator_range']]],
  ['functions_12',['Functions',['../md_doc_2advanced.html#autotoc_md29',1,'']]],
  ['functions_13',['functions',['../md_doc_2advanced.html#autotoc_md28',1,'Using low-level functions'],['../md_doc_2advanced.html#autotoc_md27',1,'Using the low-level varint and zigzag encoding and decoding functions']]]
];
